@@ -2,8 +2,11 @@ structure(list(
     url = "https://app.crunch.io/api/",
     status_code = 503,
     times = structure(c(0, 0, 0, 0, 0, 26),
-        .Names = c("redirect", "namelookup", "connect", "pretransfer",
-            "starttransfer", "total")),
+        .Names = c(
+            "redirect", "namelookup", "connect", "pretransfer",
+            "starttransfer", "total"
+        )
+    ),
     request = list(
         method = "GET",
         url = "https://app.crunch.io/api/"
@@ -11,5 +14,7 @@ structure(list(
     headers = list(
         `Retry-After` = .01
     ),
-    content = as.raw(c(0x6e, 0x75, 0x6c, 0x6c))),
-    class = "response")
+    content = as.raw(c(0x6e, 0x75, 0x6c, 0x6c))
+),
+class = "response"
+)
