@@ -14,10 +14,12 @@ with_mock_crunch({
     test_that("CrunchDataset class (re-)init preserves object state", {
         expect_identical(CrunchDataset(ds), ds)
         expect_identical(CrunchDataset(ds[, "gender"]), ds[, "gender"])
-        expect_identical(CrunchDataset(ds[ds$gender == "Female",]),
-            ds[ds$gender == "Female",])
+        expect_identical(
+            CrunchDataset(ds[ds$gender == "Female", ]),
+            ds[ds$gender == "Female", ]
+        )
         # Now confirm the same with subclasses
-        SubDataset <- setClass("SubDataset", contains="CrunchDataset")
+        SubDataset <- setClass("SubDataset", contains = "CrunchDataset")
         expect_is(SubDataset(ds), "SubDataset")
         expect_identical(names(SubDataset(ds[, "gender"])), "gender")
     })
@@ -129,7 +131,10 @@ with_mock_crunch({
     test_that("setPopulation handles datasets with no population values", {
         expect_error(
             setPopulation(ds2, magnitude = 3),
-            "Dataset does not have a population, please set one before attempting to change magnitude"
+            paste0(
+                "Dataset does not have a population, please set one before ",
+                "attempting to change magnitude"
+            )
         )
         expect_warning(
             expect_PATCH(
@@ -324,8 +329,10 @@ with_mock_crunch({
     test_that("Setting variable metadata on the dataset", {
         # See other tests in test-variable-catalog.R; this tests the [<- methods
         # on the dataset entity
-        expect_PATCH(names(variables(ds[1])) <- "year of birth",
-            'https://app.crunch.io/api/datasets/1/variables/', '{"element":"shoji:catalog","index":{',
+        expect_PATCH(
+            names(variables(ds[1])) <- "year of birth",
+            "https://app.crunch.io/api/datasets/1/variables/",
+            '{"element":"shoji:catalog","index":{',
             '"https://app.crunch.io/api/datasets/1/variables/birthyr/":{',
             '"name":"year of birth"}}}'
         )
@@ -440,7 +447,8 @@ with_mock_crunch({
     })
     test_that("Can set a variable as weight", {
         expect_PATCH(
-            settings(ds)$weight <- ds$gender, ## Silly; server would reject, but just checking request
+            ## Silly; server would reject, but just checking request
+            settings(ds)$weight <- ds$gender,
             "https://app.crunch.io/api/datasets/1/settings/",
             '{"weight":"https://app.crunch.io/api/datasets/1/variables/gender/"}'
         )
@@ -477,8 +485,10 @@ with_mock_crunch({
             paste(dQuote("this is totally not a dataset"), "not found")
         ))
         test_that("deleteDataset by index (is no longer supported)", {
-            expect_error(deleteDataset(4),
-                "deleteDataset requires either a Dataset, a unique dataset name, or a URL")
+            expect_error(
+                deleteDataset(4),
+                "deleteDataset requires either a Dataset, a unique dataset name, or a URL"
+            )
         })
         expect_error(deleteDataset(ds), "Must confirm")
         expect_error(
@@ -488,8 +498,10 @@ with_mock_crunch({
                 "To delete, please identify the dataset uniquely by URL or path."
             )
         )
-        expect_error(deleteDataset("http://app.crunch.io/api/"),
-            "http://app.crunch.io/api/ is not a valid dataset URL")
+        expect_error(
+            deleteDataset("http://app.crunch.io/api/"),
+            "http://app.crunch.io/api/ is not a valid dataset URL"
+        )
     })
 
     test_that("Dashboard URL", {
