@@ -11,18 +11,23 @@ with_mock_crunch({
             '{"categories":'
         )
     })
-    test_that("If an subvariables gets NA assigned and it doesn't have No Data, we add that category to its parent", {
-        expect_PATCH(
-            ds2$mymrset[[1]][3] <- NA,
-            "https://app.crunch.io/api/datasets/2/variables/mymrset/",
-            '{"categories":'
-        )
-    })
+    test_that(
+        paste0(
+            "If an subvariables gets NA assigned and it doesn't have No Data, ",
+            "we add that category to its parent"
+        ), {
+            expect_PATCH(
+                ds2$mymrset[[1]][3] <- NA,
+                "https://app.crunch.io/api/datasets/2/variables/mymrset/",
+                '{"categories":'
+            )
+        }
+    )
     test_that("is.na<- sends an expression", {
         expect_POST(
             is.na(ds$birthyr) <- ds$birthyr > 2016,
             "https://app.crunch.io/api/datasets/1/table/", '{"command":"update","variables":',
-            '{"https://app.crunch.io/api/datasets/1/variables/birthyr/":{"value":{"?":-1},',
+            '{"https://app.crunch.io/api/datasets/1/variables/birthyr/":{"value":null,',
             '"type":{"class":"numeric"}}},"filter":{"function":">","args":',
             '[{"variable":"https://app.crunch.io/api/datasets/1/variables/birthyr/"},',
             '{"value":2016}]}}'
@@ -132,37 +137,38 @@ with_test_authentication({
         )
     })
 
-    test_that("If No Data isn't a category, it is added automatically to categorical", {
-        ## Create a clean categorical
-        ds$cat <- VarDef(
-            values = rep(1, nrow(ds)),
-            type = "categorical",
-            categories = list(
-                list(id = 1L, name = "B", numeric_value = 1L, missing = FALSE)
-            ),
-            name = "All B"
-        )
-        expect_equal(ids(categories(ds$cat)), 1)
-        ds$cat[5] <- NA
-        expect_equal(ids(categories(ds$cat)), c(1, -1))
-        expect_equal(as.vector(ds$cat[3:7], mode = "id"), c(1, 1, -1, 1, 1))
-    })
-    test_that("If No Data isn't a category, it is added automatically to array", {
-        ## Set up for next tests. Deep copy array, purge its missings,
-        ## remove No Data category.
-        generate_categorical <- function() {
-            v <- VariableDefinition(factor(sample(c("cat", "dog"), 20, replace = TRUE)))
-            v$categories <- v$categories[1:2]
-            return(v)
-        }
-        ds$sub1 <- generate_categorical()
-        ds$sub2 <- generate_categorical()
-        ds$array <- makeArray(ds[, c("sub1", "sub2")], name = "array")
-        expect_equal(ids(categories(ds$array)), c(1, 2))
-        ds$array[[1]][5] <- NA
-        expect_equal(ids(categories(ds$array)), c(1, 2, -1))
-        expect_equal(as.vector(ds$array[[1]][5], mode = "id"), -1)
-    })
+    # skip("Transitioning to an API that does this for us")
+    # test_that("If No Data isn't a category, it is added automatically to categorical", {
+    #     ## Create a clean categorical
+    #     ds$cat <- VarDef(
+    #         values = rep(1, nrow(ds)),
+    #         type = "categorical",
+    #         categories = list(
+    #             list(id = 1L, name = "B", numeric_value = 1L, missing = FALSE)
+    #         ),
+    #         name = "All B"
+    #     )
+    #     expect_equal(ids(categories(ds$cat)), 1)
+    #     ds$cat[5] <- NA
+    #     expect_equal(ids(categories(ds$cat)), c(1, -1))
+    #     expect_equal(as.vector(ds$cat[3:7], mode = "id"), c(1, 1, -1, 1, 1))
+    # })
+    # test_that("If No Data isn't a category, it is added automatically to array", {
+    #     ## Set up for next tests. Deep copy array, purge its missings,
+    #     ## remove No Data category.
+    #     generate_categorical <- function() {
+    #         v <- VariableDefinition(factor(sample(c("cat", "dog"), 20, replace = TRUE)))
+    #         v$categories <- v$categories[1:2]
+    #         return(v)
+    #     }
+    #     ds$sub1 <- generate_categorical()
+    #     ds$sub2 <- generate_categorical()
+    #     ds$array <- makeArray(ds[, c("sub1", "sub2")], name = "array")
+    #     expect_equal(ids(categories(ds$array)), c(1, 2))
+    #     ds$array[[1]][5] <- NA
+    #     expect_equal(ids(categories(ds$array)), c(1, 2, -1))
+    #     expect_equal(as.vector(ds$array[[1]][5], mode = "id"), -1)
+    # })
 
     ## Roll it back, do some more updating
     ds <- restoreVersion(ds, 1)
